@@ -1,16 +1,16 @@
-from bionetgen.utils.utils import run_command
 import cement
-import subprocess, os
 import bionetgen as bng
 from cement.core.exc import CaughtSignal
-from .core.exc import BioNetGenError
+from .core.exc import BNGError
+from .core.exc import BNGVersionError
 from .core.main import runCLI
 from .core.main import plotDAT
 from .core.main import runAtomizeTool
 from .core.main import printInfo
 from .core.main import visualizeModel
 from .core.main import graphDiff
-from .core.notebook import BNGNotebook
+from .core.main import generate_notebook
+from .core.utils.utils import test_perl
 
 # pull defaults defined in core/defaults
 CONF = bng.defaults
@@ -36,10 +36,7 @@ class requireAction(argparse.Action):
             # if we don't meet requirement, warn user
             sys.tracebacklimit = 0
             if not (cur_version >= req_version):
-                raise RuntimeError(
-                    f"Version {values} is required but current version is {cver}. \n"
-                    + "Try running `pip install bionetgen --upgrade`"
-                )
+                raise BNGVersionError(cur_version, req_version)
         # return super().__call__(parser, namespace, values, option_string=option_string)
 
 
@@ -77,6 +74,14 @@ class BNGBase(cement.Controller):
             #                        help="Optional path to SED-ML file, if available the simulation \
             #                              protocol described in SED-ML will be ran")),
             (["-req", "--require"], dict(action=requireAction, type=str, default=None)),
+            (
+                ["-ll", "--log-level"],
+                {
+                    "help": 'This option allows you to select a logging level, from quietest to loudest options are: "CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG". Default is set to INFO',
+                    "default": None,
+                    "type": str,
+                },
+            ),
         ]
 
     # This overwrites the default behavior and runs the CLI object from core/main
@@ -131,8 +136,8 @@ class BNGBase(cement.Controller):
         in the command line and the configuraions set by the defaults
         as well as the end-user.
         """
-        args = self.app.pargs
-        runCLI(self.app.config, args)
+        test_perl(app=self.app)
+        runCLI(self.app)
 
     @cement.ex(
         help="Starts a Jupyter notebook to help run and analyze \
@@ -175,48 +180,8 @@ class BNGBase(cement.Controller):
         The default base template is agnostic to the model and if -i is given
         the template then will be adjusted to load in the model supplied.
         """
-        args = self.app.pargs
-        if args.input is not None:
-            # we want to use the template to write a custom notebok
-            assert args.input.endswith(
-                ".bngl"
-            ), f"File {args.input} doesn't have bngl extension!"
-            try:
-                import bionetgen
-
-                m = bionetgen.bngmodel(args.input)
-                str(m)
-            except:
-                raise RuntimeError(f"Couldn't import given model: {args.input}!")
-            notebook = BNGNotebook(
-                self.app.config["bionetgen"]["notebook"]["template"],
-                INPUT_ARG=args.input,
-            )
-        else:
-            # just use the basic notebook
-            notebook = BNGNotebook(self.app.config["bionetgen"]["notebook"]["path"])
-        # find our file name
-        if len(args.output) == 0:
-            fname = self.app.config["bionetgen"]["notebook"]["name"]
-        else:
-            fname = args.output
-        # write the notebook out
-        if os.path.isdir(fname):
-            if args.input is not None:
-                basename = os.path.basename(args.input)
-                mname = basename.replace(".bngl", "")
-                fname = mname + ".ipynb"
-            else:
-                mname = self.app.config["bionetgen"]["notebook"]["name"]
-                fname = os.path.join(args.output, mname)
-
-        notebook.write(fname)
-        # open the notebook with nbopen
-        stdout = getattr(subprocess, self.app.config["bionetgen"]["stdout"])
-        stderr = getattr(subprocess, self.app.config["bionetgen"]["stderr"])
-        if args.open:
-            command = ["nbopen", fname]
-            rc, _ = run_command(command)
+        test_perl(app=self.app)
+        generate_notebook(self.app)
 
     @cement.ex(
         help="Rudimentary plotting of gdat/cdat/scan files",
@@ -305,14 +270,7 @@ class BNGBase(cement.Controller):
 
         See bionetgen plot -h for all the allowed options.
         """
-        args = self.app.pargs
-        # we need to have gdat/cdat files
-        assert (
-            args.input.endswith(".gdat")
-            or args.input.endswith(".cdat")
-            or args.input.endswith(".scan")
-        ), "Input file has to be either a gdat or a cdat file"
-        plotDAT(args.input, args.output, kw=dict(args._get_kwargs()))
+        plotDAT(self.app)
 
     @cement.ex(
         help="Provides version information for BNG and dependencies",
@@ -334,8 +292,7 @@ class BNGBase(cement.Controller):
         Currently provides version information for BioNetGen, the BNG CLI, Perl,
         numpy, pandas, and libroadrunner. Also provides BNG2.pl and pyBNG paths.
         """
-        args = self.app.pargs
-        printInfo(self.app.config, args)
+        printInfo(self.app)
 
     @cement.ex(
         help="Provides a simple way to get various visualizations of the model.",
@@ -380,8 +337,8 @@ class BNGBase(cement.Controller):
         - Contact map: Visualize the contact map of the model
         - Regulatory graph: Visualize the regulatory graph of the model, also called atom rule graph
         """
-        args = self.app.pargs
-        visualizeModel(self.app.config, args)
+        test_perl(app=self.app)
+        visualizeModel(self.app)
 
     @cement.ex(
         help="A subcommand to compare two contact maps made by BioNetGen. "
@@ -444,9 +401,10 @@ class BNGBase(cement.Controller):
         ],
     )
     def graphdiff(self):
+        # TODO: add documentation here
         """ """
-        args = self.app.pargs
-        graphDiff(self.app.config, args)
+        test_perl(app=self.app)
+        graphDiff(self.app)
 
     @cement.ex(
         help="SBML to BNGL translator",
@@ -559,14 +517,6 @@ class BNGBase(cement.Controller):
                     "action": "store_true",
                 },
             ),
-            (
-                ["-ll", "--log-level"],
-                {
-                    "help": 'This option allows you to select a logging level, from quietest to loudest options are: "CRITICAL", "ERROR", "WARNING", "INFO", "DEBUG". Default is set to WARNING',
-                    "default": "WARNING",
-                    "type": str,
-                },
-            ),
             (
                 ["-omf", "--obs-map-file"],
                 {
@@ -586,8 +536,7 @@ class BNGBase(cement.Controller):
         ],
     )
     def atomize(self):
-        args = self.app.pargs
-        runAtomizeTool(self.app.config, args)
+        runAtomizeTool(self.app)
 
 
 class BioNetGen(cement.App):
@@ -668,20 +617,22 @@ def main():
         except AssertionError as e:
             print("AssertionError > %s" % e.args[0])
             app.exit_code = 1
+            # TODO: figure out if this is what we want,
+            # rn it prints stuff twice
+            # if app.debug is True:
+            #     import traceback
 
-            if app.debug is True:
-                import traceback
+            #     traceback.print_exc()
 
-                traceback.print_exc()
-
-        except BioNetGenError as e:
-            print("BioNetGenError > %s" % e.args[0])
+        except BNGError as e:
+            print("BNGError > %s" % e.args[0])
             app.exit_code = 1
+            # TODO: figure out if this is what we want,
+            # rn it prints stuff twice
+            # if app.debug is True:
+            #     import traceback
 
-            if app.debug is True:
-                import traceback
-
-                traceback.print_exc()
+            #     traceback.print_exc()
 
         except CaughtSignal as e:
             # Default Cement signals are SIGINT and SIGTERM, exit 0 (non-error)
