@@ -6,7 +6,7 @@ from .structs import Parameter, Compartment, Observable
 from .structs import MoleculeType, Species, Function
 from .structs import Rule, Action
 from .structs import EnergyPattern, PopulationMap
-from bionetgen.utils.utils import ActionList
+from bionetgen.core.utils.utils import ActionList
 
 # this import fails on some python versions
 try:
@@ -596,7 +596,7 @@ class ActionBlock(ModelBlock):
             print("Item {} not found".format(key))
 
     def __iter__(self):
-        return self.items.__iter__()
+        return range(len(self.items)).__iter__()
 
     def __contains__(self, key) -> bool:
         return (key in self.items) or (key in [x.name for x in self.items])
