@@ -1,6 +1,7 @@
 import copy
 
 from bionetgen.main import BioNetGen
+from bionetgen.core.exc import BNGModelError
 from tempfile import TemporaryFile
 from .bngparser import BNGParser
 from .blocks import (
@@ -79,6 +80,7 @@ class bngmodel:
             "actions",
         ]
         self.model_name = ""
+        self.model_path = bngl_model
         self.bngparser = BNGParser(bngl_model, generate_network=generate_network)
         self.bngparser.parse_model(self)
         for block in self.block_order:
@@ -166,6 +168,7 @@ class bngmodel:
 
     def add_parameters_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, ParameterBlock)
             self.parameters = block
             if "parameters" not in self.active_blocks:
@@ -175,6 +178,7 @@ class bngmodel:
 
     def add_compartments_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, CompartmentBlock)
             self.compartments = block
             if "compartments" not in self.active_blocks:
@@ -184,6 +188,7 @@ class bngmodel:
 
     def add_molecule_types_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, MoleculeTypeBlock)
             self.molecule_types = block
             if "molecule_types" not in self.active_blocks:
@@ -193,6 +198,7 @@ class bngmodel:
 
     def add_species_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, SpeciesBlock)
             self.species = block
             if "species" not in self.active_blocks:
@@ -202,6 +208,7 @@ class bngmodel:
 
     def add_observables_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, ObservableBlock)
             self.observables = block
             if "observables" not in self.active_blocks:
@@ -211,6 +218,7 @@ class bngmodel:
 
     def add_functions_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, FunctionBlock)
             self.functions = block
             if "functions" not in self.active_blocks:
@@ -220,6 +228,7 @@ class bngmodel:
 
     def add_rules_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, RuleBlock)
             self.rules = block
             if "rules" not in self.active_blocks:
@@ -229,6 +238,7 @@ class bngmodel:
 
     def add_energy_patterns_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, EnergyPatternBlock)
             self.energy_patterns = block
             if "energy_patterns" not in self.active_blocks:
@@ -238,6 +248,7 @@ class bngmodel:
 
     def add_population_maps_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, PopulationMapBlock)
             self.population_maps = block
             if "population_maps" not in self.active_blocks:
@@ -247,6 +258,7 @@ class bngmodel:
 
     def add_actions_block(self, block=None):
         if block is not None:
+            # TODO: Transition to BNGErrors and logging
             assert isinstance(block, ActionBlock)
             self.actions = block
             if "actions" not in self.active_blocks:
@@ -293,7 +305,10 @@ class bngmodel:
                         tpath, xml_type="sbml", bngl_str=str(self)
                     )
                 ):
-                    raise ValueError("SBML couldn't be generated for libRR simulator")
+                    raise BNGModelError(
+                        self.model_path,
+                        message="SBML couldn't be generated for libRR simulator",
+                    )
                 # TODO: Only clear the writeSBML action
                 # by adding a mechanism to do so
                 self.actions.clear_actions()
