@@ -1,7 +1,7 @@
 import os
 from tempfile import TemporaryDirectory
 from bionetgen.main import BioNetGen
-from bionetgen.tools import BNGCLI
+from bionetgen.core.tools import BNGCLI
 
 # This allows access to the CLIs config setup
 app = BioNetGen()
@@ -35,9 +35,8 @@ def run(inp, out=None, suppress=False, timeout=None):
             except Exception as e:
                 os.chdir(cur_dir)
                 # TODO: Better error reporting
-                print("Couldn't run the simulation")
-                print(e)
-                raise
+                print("Couldn't run the simulation, see error")
+                raise e
     else:
         # instantiate a CLI object with the info
         cli = BNGCLI(inp, out, conf["bngpath"], suppress=suppress, timeout=timeout)
@@ -47,7 +46,6 @@ def run(inp, out=None, suppress=False, timeout=None):
         except Exception as e:
             os.chdir(cur_dir)
             # TODO: Better error reporting
-            print("Couldn't run the simulation")
-            print(e)
-            raise
+            print("Couldn't run the simulation, see error")
+            raise e
     return cli.result
