@@ -28,6 +28,18 @@ def sim_getter(model_file=None, model_str=None, sim_type="libRR"):
         A simulator object with an API that's supposed to be agnostic to the
         underlying simulator it's running.
     """
+    if model_str is not None and model_file is None:
+        from tempfile import NamedTemporaryFile
+
+        with NamedTemporaryFile("w+") as model_file_obj:
+            model_file_obj.write(model_str)
+            model_file = model_file_obj.name
+            if sim_type == "libRR":
+                return libRRSimulator(model_file=model_file)
+            elif sim_type == "cpy":
+                return CSimulator(model_file=model_file, generate_network=True)
+            else:
+                print("simulator type {} not supported".format(sim_type))
     if model_file is not None:
         if sim_type == "libRR":
             return libRRSimulator(model_file=model_file)
